@@ -5,10 +5,13 @@
 #include <fcntl.h>
 #include <dirent.h>
 #include <cstdio>
-#include <mntent.h>
+#include <fstab.h>
 #include <iostream>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <unistd.h>
 
+#include "config.h"
 #include "mythcontext.h"
 
 // For testing
@@ -17,7 +20,11 @@
 #endif
 
 #ifndef MNTTYPE_ISO9660
+#ifdef linux
 #define MNTTYPE_ISO9660 "iso9660"
+#elif defined(__FreeBSD__) || defined(CONFIG_DARWIN)
+#define MNTTYPE_ISO9660 "cd9660"
+#endif
 #endif
 
 #ifndef MNTTYPE_UDF
@@ -35,6 +42,23 @@
 
 using namespace std;
 
+MediaMonitor *theMonitor = NULL;
+
+
+MediaMonitor* MediaMonitor::getMediaMonitor()
+{
+    if (!theMonitor)
+    {
+        if (gContext->GetNumSetting("MonitorDrives") == 1)
+        {
+            theMonitor = new MediaMonitor(NULL, 500, true);
+            theMonitor->addFSTab();
+        }
+    }
+
+    return theMonitor;
+}
+
 // MonitorThread
 MonitorThread::MonitorThread(MediaMonitor* pMon, unsigned long interval) 
              : QThread()
@@ -69,24 +93,24 @@ MediaMonitor::MediaMonitor(QObject* par, unsigned long interval,
 // Loop through the file system table and add any supported devices.
 bool MediaMonitor::addFSTab()
 {
-    struct mntent * mep = NULL;
-    FILE* vt = NULL;
+    struct fstab * mep = NULL;
     
     // Attempt to open the file system descriptor entry.
-    if ((vt = setmntent("/etc/fstab", "r")) == NULL) 
+    if (!setfsent()) 
     {
-        perror("setmntent");
-        cerr << "MediaMonitor::addFSTab - Failed to open /etc/fstab for "
-                "reading." << endl;
+        perror("setfsent");
+        cerr << "MediaMonitor::addFSTab - Failed to open "
+                _PATH_FSTAB
+                " for reading." << endl;
         return false;
     }
     else 
     {
         // Add all the entries
-        while ((mep = getmntent(vt))!=NULL)
-            addDevice(mep->mnt_fsname);
+        while ((mep = getfsent()) != NULL)
+            (void) addDevice(mep);
         
-        endmntent(vt);
+        endfsent();
     }
 
     if (m_Devices.isEmpty())
@@ -103,6 +127,96 @@ void MediaMonitor::addDevice(MythMediaDevice* pDevice)
     m_Devices.push_back( pDevice );
 }
 
+// Given a fstab entry to a media device determine what type of device it is 
+bool MediaMonitor::addDevice(struct fstab * mep) 
+{
+    QString devicePath( mep->fs_spec );
+    //cout << "addDevice - " << devicePath << endl;
+
+    MythMediaDevice* pDevice = NULL;
+    struct stat sbuf;
+
+    bool is_supermount = false;
+    bool is_cdrom = false;
+
+    if (mep == NULL)
+       return false;
+
+    if (stat(mep->fs_spec, &sbuf) < 0)
+       return false;   
+
+    //  Can it be mounted?  
+    if ( ! ( ((strstr(mep->fs_mntops, "owner") && 
+        (sbuf.st_mode & S_IRUSR)) || strstr(mep->fs_mntops, "user")) && 
+        (strstr(mep->fs_vfstype, MNTTYPE_ISO9660) || 
+         strstr(mep->fs_vfstype, MNTTYPE_UDF) || 
+         strstr(mep->fs_vfstype, MNTTYPE_AUTO)) ) ) 
+    {
+       if ( strstr(mep->fs_mntops, MNTTYPE_ISO9660) && 
+            strstr(mep->fs_vfstype, MNTTYPE_SUPERMOUNT) ) 
+          {
+             is_supermount = true;
+          }
+          else
+          {
+             return false;
+          }
+     }
+
+     if (strstr(mep->fs_mntops, MNTTYPE_ISO9660)  || 
+         strstr(mep->fs_vfstype, MNTTYPE_ISO9660) || 
+         strstr(mep->fs_vfstype, MNTTYPE_UDF)     || 
+         strstr(mep->fs_vfstype, MNTTYPE_AUTO)) 
+     {
+         is_cdrom = true;
+         //cout << "Device is a CDROM" << endl;
+     }
+
+     if (!is_supermount) 
+     {
+         if (is_cdrom)
+             pDevice = MythCDROM::get(this, QString(mep->fs_spec),
+                                     is_supermount, m_AllowEject);
+     }
+     else 
+     {
+         char *dev;
+         int len = 0;
+         dev = strstr(mep->fs_mntops, SUPER_OPT_DEV);
+         dev += sizeof(SUPER_OPT_DEV)-1;
+         while (dev[len] != ',' && dev[len] != ' ' && dev[len] != 0)
+             len++;
+
+         if (dev[len] != 0) 
+         {
+             char devstr[256];
+             strncpy(devstr, dev, len);
+             devstr[len] = 0;
+             if (is_cdrom)
+                 MythCDROM::get(this, QString(devstr),
+                                is_supermount, m_AllowEject);
+         }
+         else
+             return false;   
+     }
+        
+     if (pDevice) 
+     {
+         pDevice->setMountPath(mep->fs_file);
+         VERBOSE(VB_ALL, QString("Mediamonitor: Adding %1")
+                         .arg(pDevice->getDevicePath()));
+         if (pDevice->testMedia() == MEDIAERR_OK) 
+         {
+             addDevice(pDevice);
+             return true;
+         }
+            else
+                delete pDevice;
+      }
+
+     return false;
+}
+
 // Given a path to a media device determine what type of device it is and 
 // add it to our collection.
 bool MediaMonitor::addDevice(const char* devPath ) 
@@ -110,14 +224,8 @@ bool MediaMonitor::addDevice(const char* devPath )
     QString devicePath( devPath );
     //cout << "addDevice - " << devicePath << endl;
 
-    MythMediaDevice* pDevice = NULL;
-
-    struct mntent * mep=0;
-    FILE* vt;
+    struct fstab * mep = NULL;
     char lpath[PATH_MAX];
-    struct stat sbuf;
-    bool is_supermount = false;
-    bool is_cdrom = false;
 
     // Resolve the simlink for the device.
     int len = readlink(devicePath, lpath, PATH_MAX);
@@ -125,103 +233,40 @@ bool MediaMonitor::addDevice(const char* devPath )
         lpath[len] = 0;
 
     // Attempt to open the file system descriptor entry.
-    if ((vt = setmntent("/etc/fstab", "r")) == NULL) 
+    if (!setfsent()) 
     {
-        cout << "couldn't open the fstab" << endl;
+        perror("setfsent");
+        cerr << "MediaMonitor::addDevice - Failed to open "
+                _PATH_FSTAB
+                " for reading." << endl;
         return false;
     }
     else 
     {
         // Loop over the file system descriptor entry.
-        while ((mep = getmntent(vt)) != NULL)  
+        while ((mep = getfsent()) != NULL)  
         {
 //             cout << "***************************************************" << endl;
 //              cout << "devicePath == " << devicePath << endl;
-//              cout << "mep->mnt_fsname == " << mep->mnt_fsname << endl;
+//              cout << "mep->fs_spec == " << mep->fs_spec << endl;
 //              cout << "lpath == " << lpath << endl; 
-//              cout << "strcmp(devicePath, mep->mnt_fsname) == " << strcmp(devicePath, mep->mnt_fsname) << endl;
+//              cout << "strcmp(devicePath, mep->fs_spec) == " << strcmp(devicePath, mep->fs_spec) << endl;
 //              cout << "len ==" << len << endl;
-//              cout << "strcmp(lpath, mep->mnt_fsname)==" << strcmp(lpath, mep->mnt_fsname) << endl;
+//              cout << "strcmp(lpath, mep->fs_spec)==" << strcmp(lpath, mep->fs_spec) << endl;
 //              cout <<endl << endl;
 
             // Check to see if this is the same as our passed in device. 
-            if ((strcmp(devicePath, mep->mnt_fsname) != 0) && 
-                 (len && (strcmp(lpath, mep->mnt_fsname) != 0)))
+            if ((strcmp(devicePath, mep->fs_spec) != 0) && 
+                 (len && (strcmp(lpath, mep->fs_spec) != 0)))
                 continue;
 
-            stat(mep->mnt_fsname, &sbuf);
-
-            if (((strstr(mep->mnt_opts, "owner") && 
-                (sbuf.st_mode & S_IRUSR)) || strstr(mep->mnt_opts, "user")) && 
-                (strstr(mep->mnt_type, MNTTYPE_ISO9660) || 
-                 strstr(mep->mnt_type, MNTTYPE_UDF) || 
-                 strstr(mep->mnt_type, MNTTYPE_AUTO))) 
-            {
-                break;        
-            }
-
-            if (strstr(mep->mnt_opts, MNTTYPE_ISO9660) && 
-                strstr(mep->mnt_type, MNTTYPE_SUPERMOUNT)) 
-            {
-                is_supermount = true;
-                break;
-            }
         }
 
-        endmntent(vt);
+        endfsent();
     }
 
     if (mep) 
-    {
-        if (strstr(mep->mnt_opts, MNTTYPE_ISO9660) || 
-            strstr(mep->mnt_type, MNTTYPE_ISO9660)) 
-        {
-            is_cdrom = true;
-            //cout << "Device is a CDROM" << endl;
-        }
-
-        if (!is_supermount) 
-        {
-            if (is_cdrom)
-                pDevice = new MythCDROM(this, QString(mep->mnt_fsname),
-                                        is_supermount, m_AllowEject);
-        }
-        else 
-        {
-            char *dev;
-            int len = 0;
-            dev = strstr(mep->mnt_opts, SUPER_OPT_DEV);
-            dev += sizeof(SUPER_OPT_DEV)-1;
-            while (dev[len] != ',' && dev[len] != ' ' && dev[len] != 0)
-                len++;
-
-            if (dev[len] != 0) 
-            {
-                char devstr[256];
-                strncpy(devstr, dev, len);
-                devstr[len] = 0;
-                if (is_cdrom)
-                    pDevice = new MythCDROM(this, QString(devstr),
-                                            is_supermount, m_AllowEject);
-            }
-            else
-                return false;   
-        }
-        
-        if (pDevice) 
-        {
-            pDevice->setMountPath(mep->mnt_dir);
-            VERBOSE(VB_ALL, QString("Mediamonitor: Adding %1")
-                            .arg(pDevice->getDevicePath()));
-            if (pDevice->testMedia() == MEDIAERR_OK) 
-            {
-                addDevice(pDevice);
-                return true;
-            }
-            else
-                delete pDevice;
-        }
-    }
+       return addDevice(mep); 
 
     return false;
 }
@@ -261,6 +306,23 @@ void MediaMonitor::stopMonitoring()
     m_Thread.wait();
 }
 
+// Ask for available media
+QValueList <MythMediaDevice*> MediaMonitor::getMedias(MediaType mediatype)
+{
+    QValueList <MythMediaDevice*> medias;
+    QValueList <MythMediaDevice*>::Iterator itr = m_Devices.begin();
+    MythMediaDevice* pDev;
+    while (itr!=m_Devices.end())
+    {
+        pDev = *itr;
+        if ((pDev->getMediaType()==mediatype) &&
+            ((pDev->getStatus()==MEDIASTAT_USEABLE) ||
+            (pDev->getStatus()==MEDIASTAT_MOUNTED)))
+            medias.push_back(pDev);
+        itr++;
+    }
+    return medias;
+}
 // Signal handler.
 void MediaMonitor::mediaStatusChanged(MediaStatus oldStatus, 
                                       MythMediaDevice* pMedia)
