@@ -3,6 +3,7 @@ using namespace std;
 
 #include <qpixmap.h>
 #include <qimage.h>
+#include <qapplication.h>
 
 #include "uiphoneentry.h"
 #include "mythcontext.h"
@@ -15,7 +16,7 @@ UIPhoneEntry::UIPhoneEntry(MythMainWindow *parent, MythDialog *bg,
             : MythDialog(parent, name)
 {
     m_active = false;
-    m_lastKey = -1;
+    m_lastKey = "";
     m_lastIndex = 0;
     m_drawBlink = false;
     m_inDelay = false;
