@@ -31,10 +31,11 @@ class MpegRecorder : public RecorderBase
     bool GetPause(void);
     void WaitForPause(void);
     bool IsRecording(void);
-    bool IsErrored(void) { return false; }
+    bool IsErrored(void) { return errored; }
 
     long long GetFramesWritten(void);
 
+    bool Open(void);
     int GetVideoFd(void);
 
     long long GetKeyframePosition(long long desired);
@@ -47,6 +48,13 @@ class MpegRecorder : public RecorderBase
     bool PacketHasHeader(unsigned char *buf, int len, unsigned int startcode);
     void ProcessData(unsigned char *buffer, int len);
 
+    bool OpenMpegFileAsInput(void);
+    bool OpenV4L2DeviceAsInput(void);
+
+    bool errored;
+    bool deviceIsMpegFile;
+    int bufferSize;
+
     bool recording;
     bool encoding;
 
@@ -70,8 +78,8 @@ class MpegRecorder : public RecorderBase
     bool gopset;
 
     QMap<long long, long long> positionMap;
+    QMap<long long, long long> positionMapDelta;
 
-    long long prev_gop_save_pos;
     static const int audRateL1[];
     static const int audRateL2[];
     static const char* streamType[];
