@@ -2,6 +2,7 @@
 #define SR_ITEMS_H
 #include <qsqldatabase.h>
 #include "mythcontext.h"
+#include "mythdbcon.h"
 #include "managedlist.h"
 #include "scheduledrecording.h"
 #include "recordingprofile.h"
@@ -171,23 +172,29 @@ class SRRecordingType : public SRSelectSetting
         }
 
 
-        void addNormalSelections(bool haschannel)
+        void addNormalSelections(bool haschannel, bool ismanual)
         {
             addSelection(QObject::tr("Do not record this program"), kNotRecording);
 
             if (haschannel)
                 addSelection(QObject::tr("Record only this showing"), kSingleRecord);
-
-            addSelection(QObject::tr("Record one showing of this program"), kFindOneRecord);
+            if (!ismanual)
+                addSelection(QObject::tr("Record one showing of this title"), kFindOneRecord);
 
             if (haschannel)
-            {
                 addSelection(QObject::tr("Record in this timeslot every week"), kWeekslotRecord);
-                addSelection(QObject::tr("Record in this timeslot every day"),  kTimeslotRecord);
-                addSelection(QObject::tr("Record at any time on this channel"), kChannelRecord);
-            }
+            if (!ismanual)
+                addSelection(QObject::tr("Record one showing of this title every week"), kFindWeeklyRecord);
 
-           addSelection(QObject::tr("Record at any time on any channel"), kAllRecord);
+            if (haschannel)
+                addSelection(QObject::tr("Record in this timeslot every day"),  kTimeslotRecord);
+            if (!ismanual)
+                addSelection(QObject::tr("Record one showing of this title every day"), kFindDailyRecord);
+
+            if (haschannel && !ismanual)
+                addSelection(QObject::tr("Record at any time on this channel"), kChannelRecord);
+            if (!ismanual)
+                addSelection(QObject::tr("Record at any time on any channel"), kAllRecord);
         }
 
         void addOverrideSelections(void)
@@ -205,7 +212,7 @@ class SRStartOffset : public SRBoundedIntegerSetting
 {
     public:
         SRStartOffset(ScheduledRecording& _parent, ManagedListGroup* _group, ManagedList* _list)
-                     : SRBoundedIntegerSetting( -120, 120, 10, 1, _parent, "startoffsetList", "startoffset",
+                     : SRBoundedIntegerSetting( -480, 480, 10, 1, _parent, "startoffsetList", "startoffset",
                                                 _group, _list, true)
         {
             setTemplates(QObject::tr("Start recording %1 minutes late"),
@@ -224,10 +231,11 @@ class SREndOffset : public SRBoundedIntegerSetting
 {
     public:
         SREndOffset(ScheduledRecording& _parent, ManagedListGroup* _group, ManagedList* _list)
-                     : SRBoundedIntegerSetting( -120, 240, 10, 1, _parent, "endoffsetList", "endoffset",
+                     : SRBoundedIntegerSetting( -480, 480, 10, 1, _parent, "endoffsetList", "endoffset",
                                                 _group, _list)
         {
-            setTemplates(QObject::tr("End recording %1 minutes early"), QObject::tr("End recording %1 minute early"),
+            setTemplates(QObject::tr("End recording %1 minutes early"), 
+                         QObject::tr("End recording %1 minute early"),
                          QObject::tr("End recording on time"), QObject::tr("End recording %1 minute late"),
                          QObject::tr("End recording %1 minutes late"));
 
@@ -242,6 +250,8 @@ class SRDupIn : public SRSelectSetting
         SRDupIn(ScheduledRecording& _parent, ManagedList* _list, ManagedListGroup* _group)
             : SRSelectSetting(_parent, "dupInList", "[ Check for duplicates in ]", _group, "dupin", _list )
         {
+            if (gContext->GetNumSetting("HaveRepeats", 0))
+                addSelection(QObject::tr("Record new episodes only"), kDupsNewEpi);
             addSelection(QObject::tr("Look for duplicates in current and previous recordings"), kDupsInAll);
             addSelection(QObject::tr("Look for duplicates in current recordings only"), kDupsInRecorded);
             addSelection(QObject::tr("Look for duplicates in previous recordings only"), kDupsInOldRecorded);
@@ -258,9 +268,6 @@ class SRDupMethod: public SRSelectSetting
             : SRSelectSetting(_parent, "dupMethodList", QObject::tr("[ Match duplicates with ]"), _group,
                               "dupmethod", _list)
         {
-            if (gContext->GetNumSetting("HaveRepeats", 0))
-                addSelection(QObject::tr("Record new episodes only"), kDupCheckNewEpi);
-
             addSelection(QObject::tr("Match duplicates using subtitle & description"), kDupCheckSubDesc);
             addSelection(QObject::tr("Match duplicates using subtitle"), kDupCheckSub);
             addSelection(QObject::tr("Match duplicates using description"), kDupCheckDesc);
@@ -284,20 +291,21 @@ class SRRecSearchType: public IntegerSetting, public SimpleSRSetting
 class SRProfileSelector: public SRSelectSetting {
     public:
         SRProfileSelector(ScheduledRecording& _parent, ManagedList* _list, ManagedListGroup* _group)
-            : SRSelectSetting(_parent, "profileList", QObject::tr("[ Select recording Profile ]"), _group, "profile", _list )
+            : SRSelectSetting(_parent, "profileList", QObject::tr("[ Select recording Profile ]"), _group,
+                              "profile", _list )
         {
             _parent.setProfileObj(this);
         }
 
 
-        virtual void load(QSqlDatabase* db) {
-            fillSelections(db);
-            SRSelectSetting::load(db);
+        virtual void load() {
+            fillSelections();
+            SRSelectSetting::load();
         }
 
-        virtual void fillSelections(QSqlDatabase* db) {
+        virtual void fillSelections() {
             clearSelections();
-            RecordingProfile::fillSelections(db, selectItem, 0);
+            RecordingProfile::fillSelections(selectItem, 0);
         }
 };
 
@@ -306,7 +314,8 @@ class SRSchedOptionsGroup : public ManagedListGroup
     Q_OBJECT
 
     public:
-        SRSchedOptionsGroup(ScheduledRecording& _rec, ManagedList* _list, ManagedListGroup* _group, QObject* _parent);
+        SRSchedOptionsGroup(ScheduledRecording& _rec, ManagedList* _list, ManagedListGroup* _group, 
+                            QObject* _parent);
 
         void setEnabled(bool isScheduled, bool multiEpisode);
 
@@ -316,6 +325,7 @@ class SRSchedOptionsGroup : public ManagedListGroup
     protected:
 
         friend class SRRootGroup;
+        class SRInactive* inactive;
         class SRRecPriority* recPriority;
         class SRStartOffset* startOffset;
         class SREndOffset* endOffset;
@@ -325,13 +335,34 @@ class SRSchedOptionsGroup : public ManagedListGroup
         ScheduledRecording& schedRec;
 };
 
+class SRJobQueueGroup : public ManagedListGroup
+{
+    Q_OBJECT
+    
+    public:
+        SRJobQueueGroup(ScheduledRecording& _rec, ManagedList* _list, ManagedListGroup* _group, QObject* _parent);
+        
+    protected:
+
+        friend class SRRootGroup;
+        class SRAutoTranscode* autoTranscode;
+        class SRAutoCommFlag* autoCommFlag;
+        class SRAutoUserJob1* autoUserJob1;
+        class SRAutoUserJob2* autoUserJob2;
+        class SRAutoUserJob3* autoUserJob3;
+        class SRAutoUserJob4* autoUserJob4;
+
+        ScheduledRecording& schedRec;
+};
+
 
 class SRStorageOptionsGroup : public ManagedListGroup
 {
     Q_OBJECT
 
     public:
-        SRStorageOptionsGroup(ScheduledRecording& _rec, ManagedList* _list, ManagedListGroup* _group, QObject* _parent);
+        SRStorageOptionsGroup(ScheduledRecording& _rec, ManagedList* _list, ManagedListGroup* _group, 
+                              QObject* _parent);
 
         void setEnabled(bool isScheduled, bool multiEpisode);
 
@@ -351,25 +382,6 @@ class SRStorageOptionsGroup : public ManagedListGroup
 };
 
 
-class SRDupSettingsGroup : public ManagedListGroup
-{
-    Q_OBJECT
-    public:
-        SRDupSettingsGroup(ScheduledRecording& _rec, ManagedList* _list, ManagedListGroup* _group, QObject* _parent);
-        virtual void doGoBack();
-        void syncText();
-
-    public slots:
-        void itemChanged(ManagedListItem*);
-
-    protected:
-
-        SRDupIn* dupLocItem;
-        SRDupMethod* dupMethItem;
-};
-
-
-
 class SRChannel: public ChannelSetting, public SimpleSRSetting
 {
     public:
@@ -487,26 +499,165 @@ class SRProgramid: public LineEditSetting, public SimpleSRSetting
         };
 };
 
+class SRFindDay: public IntegerSetting, public SimpleSRSetting
+{
+    public:
+        SRFindDay(ScheduledRecording& parent)
+            : SimpleSRSetting(parent, "findday")
+        {
+            setVisible(false);
+        }
+};
+
+class SRFindTime: public TimeSetting, public SimpleSRSetting
+{
+    public:
+        SRFindTime(ScheduledRecording& parent)
+            : SimpleSRSetting(parent, "findtime")
+        {
+            setVisible(false);
+        }
+};
+
+class SRFindId: public IntegerSetting, public SimpleSRSetting
+{
+    public:
+        SRFindId(ScheduledRecording& parent)
+            : SimpleSRSetting(parent, "findid")
+        {
+            setVisible(false);
+        }
+};
+
+class SRParentId: public IntegerSetting, public SimpleSRSetting
+{
+    public:
+        SRParentId(ScheduledRecording& parent)
+            : SimpleSRSetting(parent, "parentid")
+        {
+            setVisible(false);
+        }
+};
+
+class SRAutoTranscode: public SRSelectSetting 
+{
+    public:
+        SRAutoTranscode(ScheduledRecording& _parent, ManagedList* _list, ManagedListGroup* _group)
+            : SRSelectSetting(_parent, "autoTranscodeList", "[ Automatically Transcode ]", _group, 
+                              "autotranscode", _list) 
+        {
+            addSelection("Transcode new recordings", 1);
+            addSelection("Do not Transcode new recordings", 0);
+            setValue(0);
+            _parent.setAutoTranscodeObj(this);
+        }
+};
+
+class SRAutoCommFlag: public SRSelectSetting 
+{
+    public:
+        SRAutoCommFlag(ScheduledRecording& _parent, ManagedList* _list, ManagedListGroup* _group)
+            : SRSelectSetting(_parent, "autoCommFlagList", "[ Automatically Commercial Flag ]", _group, 
+                              "autocommflag", _list) 
+        {
+            addSelection(QObject::tr("Commercial Flag new recordings"), 1);
+            addSelection(QObject::tr("Do not Commercial Flag new recordings"), 0);
+            setValue(1);
+            _parent.setAutoCommFlagObj(this);
+        }
+};
+
+class SRAutoUserJob1: public SRSelectSetting 
+{
+    public:
+        SRAutoUserJob1(ScheduledRecording& _parent, ManagedList* _list, ManagedListGroup* _group)
+            : SRSelectSetting(_parent, "autoUserJob1List", "[ Automatically Run User Job #1 ]", _group, 
+                              "autouserjob1", _list) 
+        {
+            QString desc = gContext->GetSetting("UserJobDesc1");
+            addSelection(QObject::tr("Run '%1'").arg(desc), 1);
+            addSelection(QObject::tr("Do not run '%1' for new recordings").arg(desc), 0);
+            setValue(0);
+            _parent.setAutoUserJob1Obj(this);
+        }
+};
+
+class SRAutoUserJob2: public SRSelectSetting 
+{
+    public:
+        SRAutoUserJob2(ScheduledRecording& _parent, ManagedList* _list, ManagedListGroup* _group)
+            : SRSelectSetting(_parent, "autoUserJob2List", "[ Automatically Run User Job #2 ]", _group, 
+                              "autouserjob2", _list) 
+        {
+            QString desc = gContext->GetSetting("UserJobDesc2");
+            addSelection(QObject::tr("Run '%1'").arg(desc), 1);
+            addSelection(QObject::tr("Do not run '%1' for new recordings").arg(desc), 0);
+            setValue(0);
+            _parent.setAutoUserJob2Obj(this);
+        }
+};
+
+class SRAutoUserJob3: public SRSelectSetting 
+{
+    public:
+        SRAutoUserJob3(ScheduledRecording& _parent, ManagedList* _list, ManagedListGroup* _group)
+            : SRSelectSetting(_parent, "autoUserJob3List", "[ Automatically Run User Job #3 ]", _group, 
+                              "autouserjob3", _list) 
+        {
+            QString desc = gContext->GetSetting("UserJobDesc3");
+            addSelection(QObject::tr("Run '%1'").arg(desc), 1);
+            addSelection(QObject::tr("Do not run '%1' for new recordings").arg(desc), 0);
+            setValue(0);
+            _parent.setAutoUserJob3Obj(this);
+        }
+};
+
+class SRAutoUserJob4: public SRSelectSetting 
+{
+    public:
+        SRAutoUserJob4(ScheduledRecording& _parent, ManagedList* _list, ManagedListGroup* _group)
+            : SRSelectSetting(_parent, "autoUserJob4List", "[ Automatically Run User Job #4 ]", _group, 
+                              "autouserjob4", _list) 
+        {
+            QString desc = gContext->GetSetting("UserJobDesc4");
+            addSelection(QObject::tr("Run '%1'").arg(desc), 1);
+            addSelection(QObject::tr("Do not run '%1' for new recordings").arg(desc), 0);
+            setValue(0);
+            _parent.setAutoUserJob4Obj(this);
+        }
+};
+
 class SRAutoExpire: public SRBoolSetting
 {
     public:
         SRAutoExpire(ScheduledRecording& _parent, ManagedListGroup* _group, ManagedList* _list)
-                    : SRBoolSetting(_parent, QObject::tr("Allow auto expire"), QObject::tr("Don't allow auto expire"),
+                    : SRBoolSetting(_parent, QObject::tr("Allow auto expire"), 
+                                     QObject::tr("Don't allow auto expire"),
                                     "autoExpireItem", "autoexpire", _group, _list )
         {
             _parent.setAutoExpireObj(this);
         }
 };
 
-
+class SRInactive: public SRBoolSetting
+{
+    public:
+        SRInactive(ScheduledRecording& _parent, ManagedListGroup* _group, ManagedList* _list)
+                    : SRBoolSetting(_parent, QObject::tr("This recording schedule is inactive"), 
+                                     QObject::tr("This recording schedule is active"),
+                                    "inactiveItem", "inactive", _group, _list )
+        {
+            _parent.setInactiveObj(this);
+        }
+};
 
 class SRMaxNewest: public SRBoolSetting
 {
     public:
         SRMaxNewest(ScheduledRecording& _parent, ManagedListGroup* _group, ManagedList* _list)
-                   : SRBoolSetting(_parent, QObject::tr("Delete oldest if this would exceede the max episodes"),
-                                   QObject::tr("Don't record if this would exceed the max episodes"), "maxnewestItem",
-                                   "maxnewest", _group, _list )
+                   : SRBoolSetting(_parent, QObject::tr("Delete oldest if this would exceed the max episodes"),
+                                   QObject::tr("Don't record if this would exceed the max episodes"),
+                                   "maxnewestItem", "maxnewest", _group, _list )
         {
             setValue(false);
             _parent.setMaxNewestObj(this);
@@ -523,41 +674,13 @@ class SRMaxEpisodes : public SRBoundedIntegerSetting
                  : SRBoundedIntegerSetting( 0, 100, 5, 1, _parent, "maxepisodesList", "maxepisodes",
                                             _group, _list)
     {
-        setTemplates("", "", QObject::tr("No episode limit"), QObject::tr("Keep only one episode."), QObject::tr("Keep at most %1 episodes"));
+        setTemplates("", "", QObject::tr("No episode limit"), 
+                     QObject::tr("Keep only one episode."), QObject::tr("Keep at most %1 episodes"));
         _parent.setMaxEpisodesObj(this);
     }
 };
 
 
-class SREpisodesGroup : public ManagedListGroup
-{
-    Q_OBJECT
-
-    public:
-        SREpisodesGroup(ScheduledRecording& _rec, ManagedList* _list, ManagedListGroup* _group, QObject* _parent);
-
-        virtual void doGoBack()
-        {
-            syncText();
-            ManagedListGroup::doGoBack();
-        }
-
-
-        void syncText();
-
-    public slots:
-        void itemChanged(ManagedListItem*)
-        {
-            maxNewest->getItem()->setEnabled(maxEpisodes->getValue().toInt() !=0);
-            syncText();
-        }
-
-    protected:
-        SRMaxNewest* maxNewest;
-        SRMaxEpisodes* maxEpisodes;
-};
-
-
 class SRRecPriority: public SRBoundedIntegerSetting
 {
     public:
@@ -566,7 +689,7 @@ class SRRecPriority: public SRBoundedIntegerSetting
                                                _group, _list)
         {
             setTemplates( QObject::tr("Reduce priority by %1"), QObject::tr("Reduce priority by %1"),
-			  QObject::tr("Normal recording priority"),
+                          QObject::tr("Normal recording priority"),
                           QObject::tr("Raise priority by %1"), QObject::tr("Raise priority by %1") );
             setValue(0);
             _parent.setRecPriorityObj(this);
@@ -590,9 +713,9 @@ class SRRecGroup: public SRSelectSetting
         }
 
 
-        virtual void load(QSqlDatabase *db) {
-            fillSelections(db);
-            SRSelectSetting::load(db);
+        virtual void load() {
+            fillSelections();
+            SRSelectSetting::load();
         }
 
         virtual QString getValue(void) const {
@@ -602,37 +725,42 @@ class SRRecGroup: public SRSelectSetting
                 return settingValue;
         }
 
-        virtual void fillSelections(QSqlDatabase *db)
+        virtual void fillSelections()
         {
             addButton(QString("[ %1 ]").arg(QObject::tr("Create a new recording group")), "__NEW_GROUP__");
             connect(selectItem, SIGNAL(buttonPressed(ManagedListItem*, ManagedListItem*)), this,
                                        SLOT(showNewRecGroup()));
 
             addSelection(QString(QObject::tr("Store in the \"%1\" recording group"))
-                         .arg(QObject::tr("Default")), "Default", false);
-
+                         .arg(QObject::tr("Default")), "Default");
+            MSqlQuery query(MSqlQuery::InitCon());
             QString thequery = QString("SELECT DISTINCT recgroup from recorded "
                                        "WHERE recgroup <> 'Default'");
-            QSqlQuery query = db->exec(thequery);
+            query.prepare(thequery);
 
-            if (query.isActive() && query.numRowsAffected() > 0)
+            if (query.exec() && query.isActive() && query.size() > 0)
             {
                 while (query.next())
                 {
-                    addSelection(QString(QObject::tr("Store in the \"%1\" recording "
-                                                     "group")).arg(query.value(0).toString()),
-                                 query.value(0).toString(), false);
+                    QString recgroup = QString::fromUtf8(query.value(0).toString());
+
+                    addSelection(QString(QObject::tr("Store in the \"%1\" recording group")).arg(recgroup),
+                                 recgroup);
                 }
             }
 
             thequery = QString("SELECT DISTINCT recgroup from record "
                                "WHERE recgroup <> 'Default'");
-            query = db->exec(thequery);
+            query.prepare(thequery);
 
-            if (query.isActive() && query.numRowsAffected() > 0)
+            if (query.exec() && query.isActive() && query.size() > 0)
                 while (query.next())
-                    addSelection(QString(QObject::tr("Store in the \"%1\" recording group")).arg(query.value(0).toString()),
-                                 query.value(0).toString(), false);
+                {
+                    QString recgroup = QString::fromUtf8(query.value(0).toString());
+                    addSelection(QString(QObject::tr("Store in the \"%1\" recording group")).arg(recgroup),
+                                 recgroup);
+                }
+
         }
 
 
