@@ -6,6 +6,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <libgen.h>
 #include <signal.h>
 
 #include <iostream>
@@ -15,7 +16,6 @@ using namespace std;
 #include "tv.h"
 #include "autoexpire.h"
 #include "scheduler.h"
-#include "transcoder.h"
 #include "mainserver.h"
 #include "encoderlink.h"
 #include "remoteutil.h"
@@ -23,12 +23,14 @@ using namespace std;
 
 #include "libmythtv/programinfo.h"
 #include "libmyth/mythcontext.h"
+#include "libmyth/mythdbcon.h"
 #include "libmythtv/dbcheck.h"
+#include "libmythtv/jobqueue.h"
 
 QMap<int, EncoderLink *> tvList;
 AutoExpire *expirer = NULL;
 Scheduler *sched = NULL;
-Transcoder *trans = NULL;
+JobQueue *jobqueue = NULL;
 QString pidfile;
 QString lockfile_location;
 HouseKeeper *housekeeping = NULL;
@@ -37,7 +39,7 @@ bool setupTVs(bool ismaster)
 {
     QString localhostname = gContext->GetHostName();
 
-    QSqlQuery query;
+    MSqlQuery query(MSqlQuery::InitCon());
 
     if (ismaster)
     {
@@ -62,12 +64,14 @@ bool setupTVs(bool ismaster)
             MythContext::DBError("Querying minimum chanid",
                                  query.lastQuery());
 
-        QSqlQuery records_without_station("SELECT record.chanid,"
+        MSqlQuery records_without_station(MSqlQuery::InitCon());
+        records_without_station.prepare("SELECT record.chanid,"
                 " channel.callsign FROM record LEFT JOIN channel"
                 " ON record.chanid = channel.chanid WHERE record.station='';");
+        records_without_station.exec(); 
         if (records_without_station.first())
         {
-            QSqlQuery update_record;
+            MSqlQuery update_record(MSqlQuery::InitCon());
             update_record.prepare("UPDATE record SET station = :CALLSIGN"
                     " WHERE chanid = :CHANID;");
             do
@@ -83,36 +87,11 @@ bool setupTVs(bool ismaster)
                 }
             } while (records_without_station.next());
         }
-
-        QSqlQuery overrides_without_station("SELECT recordoverride.recordid,"
-                " channel.callsign FROM recordoverride LEFT JOIN channel"
-                " ON recordoverride.chanid = channel.chanid"
-                " WHERE recordoverride.station='';");
-        if (overrides_without_station.first())
-        {
-            QSqlQuery update_override;
-            update_override.prepare("UPDATE recordoverride"
-                    " SET station = :CALLSIGN,"
-                    " starttime=starttime, endtime=endtime"
-                    " WHERE recordid = :RECORDID;");
-            do
-            {
-                update_override.bindValue(":CALLSIGN",
-                        overrides_without_station.value(1));
-                update_override.bindValue(":RECORDID",
-                        overrides_without_station.value(0));
-                if (!update_override.exec())
-                {
-                    MythContext::DBError("Updating recordoverride station",
-                            update_override.lastQuery());
-                }
-            } while (overrides_without_station.next());
-        }
     }
 
     query.exec("SELECT cardid,hostname FROM capturecard ORDER BY cardid;");
 
-    if (query.isActive() && query.numRowsAffected())
+    if (query.isActive() && query.size())
     {
         while (query.next())
         {
@@ -128,7 +107,7 @@ bool setupTVs(bool ismaster)
                 cerr << msg;
                 gContext->LogEntry("mythbackend", LP_CRITICAL,
                                    "Problem with capture cards", msg);
-                exit(-1);
+                exit(2);
             }
 
             if (!ismaster)
@@ -178,9 +157,6 @@ void cleanup(void)
     if (sched)
         delete sched;
 
-    if (trans)
-        delete trans;
-
     if (pidfile != "")
         unlink(pidfile.ascii());
 
@@ -201,6 +177,7 @@ int main(int argc, char **argv)
     bool daemonize = false;
     bool printsched = false;
     bool testsched = false;
+    bool resched = false;
     bool nosched = false;
     bool printexpire = false;
     for (int argpos = 1; argpos < a.argc(); ++argpos)
@@ -319,11 +296,26 @@ int main(int argc, char **argv)
                             print_verbose_messages |= VB_COMMFLAG;
                             verboseString += " " + *it;
                         }
+                        else if(!strcmp(*it,"jobqueue"))
+                        {
+                            print_verbose_messages |= VB_JOBQUEUE;
+                            verboseString += " " + *it;
+                        }
                         else if(!strcmp(*it,"audio"))
                         {
                             print_verbose_messages |= VB_AUDIO;
                             verboseString += " " + *it;
                         }
+                        else if(!strcmp(*it,"libav"))
+                        {
+                            print_verbose_messages |= VB_LIBAV;
+                            verboseString += " " + *it;
+                        }
+                        else if(!strcmp(*it,"siparser"))
+                        {
+                            print_verbose_messages |= VB_SIPARSER;
+                            verboseString += " " + *it;
+                        }
                         else
                         {
                             cerr << "Unknown argument for -v/--verbose: "
@@ -346,6 +338,10 @@ int main(int argc, char **argv)
         {
             testsched = true;
         } 
+        else if (!strcmp(a.argv()[argpos],"--resched"))
+        {
+            resched = true;
+        } 
         else if (!strcmp(a.argv()[argpos],"--nosched"))
         {
             nosched = true;
@@ -372,9 +368,13 @@ int main(int argc, char **argv)
                     "-v or --verbose debug-level    Prints more information" << endl <<
                     "                               Accepts any combination (separated by comma)" << endl << 
                     "                               of all,none,quiet,record,playback,channel," << endl <<
-                    "                               osd,file,schedule,network,commflag,audio" << endl <<
+                    "                               osd,file,schedule,network,commflag,audio," << endl <<
+                    "                               libav,jobqueue" << endl <<
                     "--printexpire                  List of auto-expire programs" << endl <<
                     "--printsched                   Upcoming scheduled programs" << endl <<
+                    "--testsched                    Test run scheduler (ignore existing schedule)" << endl <<
+                    "--resched                      Force the scheduler to update" << endl <<
+                    "--nosched                      Do not perform any scheduling" << endl <<
                     "--version                      Version information" << endl;
             return -1;
         }
@@ -406,8 +406,6 @@ int main(int argc, char **argv)
         }
     }
 
-    close(0);
-
     if (signal(SIGPIPE, SIG_IGN) == SIG_ERR)
         cerr << "Unable to ignore SIGPIPE\n";
 
@@ -430,67 +428,32 @@ int main(int argc, char **argv)
         // Send stdout and stderr to the logfile
         dup2(logfd, 1);
         dup2(logfd, 2);
+
+        // Close the unduplicated logfd
+        if (logfd != 1 && logfd != 2)
+            close(logfd);
     }
 
-    gContext = new MythContext(MYTH_BINARY_VERSION, false, false);
-
-    QSqlDatabase *db = QSqlDatabase::addDatabase("QMYSQL3");
-    if (!db)
+    gContext = NULL;
+    gContext = new MythContext(MYTH_BINARY_VERSION);
+    if(!gContext->Init(false))
     {
-        cerr << "Couldn't connect to database\n";
+        VERBOSE(VB_IMPORTANT, "Failed to init MythContext, exiting.");
         return -1;
     }
+    gContext->SetBackend(true);
 
-    QSqlDatabase *subthread = QSqlDatabase::addDatabase("QMYSQL3", "SUBDB");
-    if (!subthread)
+    close(0);
+
+    if (!UpgradeTVDatabaseSchema())
     {
-        cerr << "Couldn't connect to database\n";
+        VERBOSE(VB_IMPORTANT, "Couldn't upgrade database to new schema");
         return -1;
-    }
-
-    QSqlDatabase *expthread = QSqlDatabase::addDatabase("QMYSQL3", "EXPDB");
-    if (!expthread)
-    {
-        cerr << "Couldn't connect to database\n";
-        return -1;
-    }
-
-    QSqlDatabase *hkthread = QSqlDatabase::addDatabase("QMYSQL3", "HKDB");
-    if (!hkthread)
-    {
-        cerr << "Couldn't connect to database\n";
-        return -1;
-    }
-
-    QSqlDatabase *transthread = QSqlDatabase::addDatabase("QMYSQL3", "TRANSDB");
-    if (!transthread)
-    {
-        cerr << "Couldn't connect to database\n";
-        return -1;
-    }
-
-    QSqlDatabase *msdb = QSqlDatabase::addDatabase("QMYSQL3", "MSDB");
-    if (!msdb)
-    {
-        cerr << "Couldn't connect to database\n";
-        return -1;
-    }
-
-    if (!gContext->OpenDatabase(db) || !gContext->OpenDatabase(subthread) ||
-        !gContext->OpenDatabase(expthread) ||
-        !gContext->OpenDatabase(hkthread) ||
-        !gContext->OpenDatabase(transthread) ||
-        !gContext->OpenDatabase(msdb))
-    {
-        cerr << "Couldn't open database\n";
-        return -1;
-    }
-
-    UpgradeTVDatabaseSchema();
+    }    
 
     if (printsched || testsched)
     {
-        sched = new Scheduler(false, &tvList, db);
+        sched = new Scheduler(false, &tvList);
         if (!testsched && gContext->ConnectToMasterServer())
         {
             cout << "Retrieving Schedule from Master backend.\n";
@@ -501,7 +464,7 @@ int main(int argc, char **argv)
             cout << "Calculating Schedule from database.\n" <<
                     "Inputs, Card IDs, and Conflict info may be invalid "
                     "if you have multiple tuners.\n";
-            sched->FillRecordLists();
+            sched->FillRecordListFromDB();
         }
 
         print_verbose_messages |= VB_SCHEDULE;
@@ -510,9 +473,25 @@ int main(int argc, char **argv)
         exit(0);
     }
 
+    if (resched)
+    {
+        gContext->SetBackend(false);
+
+        if (gContext->ConnectToMasterServer())
+        {
+            VERBOSE(VB_IMPORTANT, "Connected to master for reschedule");
+            ScheduledRecording::signalChange(-1);
+        }
+        else
+            VERBOSE(VB_IMPORTANT, "Cannot connect to master for reschedule");
+
+        cleanup();
+        exit(0);
+    }
+
     if (printexpire)
     {
-        expirer = new AutoExpire(false, false, db);
+        expirer = new AutoExpire(false, false);
         expirer->FillExpireList();
         expirer->PrintExpireList();
         cleanup();
@@ -532,7 +511,7 @@ int main(int argc, char **argv)
         cerr << "No setting found for this machine's BackendServerIP.\n"
              << "Please run setup on this machine and modify the first page\n"
              << "of the general settings.\n";
-        exit(-1);
+        exit(3);
     }
 
     if (masterip == myip)
@@ -557,18 +536,14 @@ int main(int argc, char **argv)
 
     if (ismaster && runsched && !nosched)
     {
-        QSqlDatabase *scdb = QSqlDatabase::database("SUBDB");
-        sched = new Scheduler(true, &tvList, scdb);
+        sched = new Scheduler(true, &tvList);
     }
 
-    QSqlDatabase *expdb = QSqlDatabase::database("EXPDB");
-    expirer = new AutoExpire(true, ismaster, expdb);
+    expirer = new AutoExpire(true, ismaster);
 
-    QSqlDatabase *hkdb = QSqlDatabase::database("HKDB");
-    housekeeping = new HouseKeeper(true, ismaster, hkdb);
+    housekeeping = new HouseKeeper(true, ismaster);
 
-    QSqlDatabase *trandb = QSqlDatabase::database("TRANSDB");
-    trans = new Transcoder(&tvList, trandb);
+    jobqueue = new JobQueue(ismaster);
 
     VERBOSE(VB_ALL, QString("%1 version: %2 www.mythtv.org")
                             .arg(binname).arg(MYTH_BINARY_VERSION));
@@ -591,12 +566,12 @@ int main(int argc, char **argv)
             cerr << "Unable to open lockfile!\n"
                  << "Be sure that \'" << gContext->GetSetting("RecordFilePrefix")
                  << "\' exists and that both \nthe directory and that "
-                 << "file are writeble by this user.\n";
+                 << "file are writeable by this user.\n";
             return -1;
         }
     }
 
-    new MainServer(ismaster, port, statusport, &tvList, msdb, sched);
+    new MainServer(ismaster, port, statusport, &tvList, sched);
 
     if (ismaster)
     {
@@ -611,8 +586,6 @@ int main(int argc, char **argv)
 
     a.exec();
 
-    // delete trans;
-
     gContext->LogEntry("mythbackend", LP_INFO, "MythBackend exiting", "");
     cleanup();
 
